summaryrefslogtreecommitdiffstats
path: root/businesslayer/feedbusinesslayer.php
diff options
context:
space:
mode:
authorBernhard Posselt <nukeawhale@gmail.com>2013-08-31 02:58:56 +0200
committerBernhard Posselt <nukeawhale@gmail.com>2013-08-31 02:58:56 +0200
commit7036a1407c3dce54a6ac5e283ba55720f85ba7de (patch)
tree7c5fae7ab816a2b0c56b92ca74ebc7cc591d5a3d /businesslayer/feedbusinesslayer.php
parent6f23208ff68d4a8bf2fc20b1fcad6b5e636fb584 (diff)
Throw proper error codes when creating invalid folders through the API, fix #297
Diffstat (limited to 'businesslayer/feedbusinesslayer.php')
-rw-r--r--businesslayer/feedbusinesslayer.php4
1 files changed, 2 insertions, 2 deletions
diff --git a/businesslayer/feedbusinesslayer.php b/businesslayer/feedbusinesslayer.php
index cf79d0b22..034209add 100644
--- a/businesslayer/feedbusinesslayer.php
+++ b/businesslayer/feedbusinesslayer.php
@@ -88,7 +88,7 @@ class FeedBusinessLayer extends BusinessLayer {
* @param string $feedUrl the url to the feed
* @param int $folderId the folder where it should be put into, 0 for root folder
* @param string $userId for which user the feed should be created
* @throws BusinessLayerExistsException if the feed exists already
* @throws BusinessLayerException if the url points to an invalid feed
* @return Feed the newly created feed
*/
@@ -100,7 +100,7 @@ class FeedBusinessLayer extends BusinessLayer {
// try again if feed exists depending on the reported link
try {
$this->mapper->findByUrlHash($feed->getUrlHash(), $userId);
- throw new BusinessLayerExistsException(
+ throw new BusinessLayerConflictException(
$this->api->getTrans()->t('Can not add feed: Exists already'));
} catch(DoesNotExistException $ex){}
@@ -88,7 +88,7 @@ class FeedBusinessLayer extends BusinessLayer {
* @param int $folderId the folder where it should be put into, 0 for root folder
* @param string $userId for which user the feed should be created
- * @throws BusinessLayerExistsException if the feed exists already
+ * @throws BusinessLayerConflictException if the feed exists already
* @throws BusinessLayerException if the url points to an invalid feed
* @return Feed the newly created feed